summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
Diffstat (limited to 'png.h')
-rw-r--r--png.h25
1 files changed, 13 insertions, 12 deletions
diff --git a/png.h b/png.h
index e1eda55ee..49da7d690 100644
--- a/png.h
+++ b/png.h
@@ -1,6 +1,6 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.0.52 - January 3, 2010
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -10,7 +10,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.0.52 - January 3, 2010: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -254,6 +254,7 @@
* 1.2.42rc01-05 13 10242 12.so.0.42[.0]
* 1.0.52 10 10052 10.so.0.52[.0]
* 1.2.42 13 10242 12.so.0.42[.0]
+ * 1.2.43beta01 13 10243 12.so.0.43[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -285,7 +286,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.0.52, January 3, 2010, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -397,13 +398,13 @@
* Y2K compliance in libpng:
* =========================
*
- * January 3, 2010
+ * January 14, 2010
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.0.52 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -459,9 +460,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.0.52"
+#define PNG_LIBPNG_VER_STRING "1.0.53beta01"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.0.52 - January 3, 2010\n"
+ " libpng version 1.0.53beta01 - January 14, 2010\n"
#define PNG_LIBPNG_VER_SONUM 0
#define PNG_LIBPNG_VER_DLLNUM 10
@@ -469,12 +470,12 @@
/* These should match the first 3 components of PNG_LIBPNG_VER_STRING: */
#define PNG_LIBPNG_VER_MAJOR 1
#define PNG_LIBPNG_VER_MINOR 0
-#define PNG_LIBPNG_VER_RELEASE 52
+#define PNG_LIBPNG_VER_RELEASE 53
/* This should match the numeric part of the final component of
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 0
+#define PNG_LIBPNG_VER_BUILD 01
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -491,7 +492,7 @@
#define PNG_LIBPNG_BUILD_SPECIAL 32 /* Cannot be OR'ed with
PNG_LIBPNG_BUILD_PRIVATE */
-#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_STABLE
+#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_BETA
/* Careful here. At one time, Guy wanted to use 082, but that would be octal.
* We must not include leading zeros.
@@ -499,7 +500,7 @@
* version 1.0.0 was mis-numbered 100 instead of 10000). From
* version 1.0.1 it's xxyyzz, where x=major, y=minor, z=release
*/
-#define PNG_LIBPNG_VER 10052 /* 1.0.52 */
+#define PNG_LIBPNG_VER 10053 /* 1.0.53 */
#ifndef PNG_VERSION_INFO_ONLY
/* Include the compression library's header */
@@ -1530,7 +1531,7 @@ struct png_struct_def
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_0_52;
+typedef png_structp version_1_0_53beta01;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,6 +1,6 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.0.52 - January 3, 2010
+ * libpng version 1.0.53beta01 - January 14, 2010
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -10,7 +10,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.0.52 - January 3, 2010: Glenn
+ * libpng versions 0.97, January 1998, through 1.0.53beta01 - January 14, 2010: Glenn
* See also "Contributing Authors", below.
*
@@ -285,7 +286,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.0.52, January 3, 2010, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.0.53beta01, January 14, 2010, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -397,13 +398,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.0.52 are Y2K compliant. It is my belief that earlier
+ * upward through 1.0.53beta01 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*